## returns 1/false in Sage views if one or more item lines have a margin lower than warning margin 
## P1 warningMargin


from accpac import *

def exceedSalesMargin(warningMargin, vDetail):
	rvspyTrace("exceedSalesMargin");
	
	ext_sales = float(vDetail.get("EXTINVMISC"))
	ext_cost = float(vDetail.get("EXTOCOST"))

	# sales margin formula:
	if (ext_sales != 0):
		salesMargin = ((ext_sales - ext_cost) / (ext_sales)) * 100
	else: 
		salesMargin = 0
	#showMessageBox (str(salesMargin))
	if (salesMargin < warningMargin):
		# return as invalid
		#showMessageBox("false", str(warningMargin))
		return False
	else:
		return True

def checkSalesMargins(e, v):
	rvspyTrace("checkSalesMargins")
	r = 0	# default to success;
	if (e.p1 == None):
		# no margin specified. Cannot perform the test.
		return 0
		
	if (e.p1 == ""):
		# no margin specified. Cannot perform the test.
		return 0
		
	try:
		warningMargin = float(e.resolve(e.p1))
		
	except Exception as ex:
		# something went wrong. Possibly P1 cannot be converted to float.
		# cannot perform the test if the warning margin is invalid.
		return 1
		
	# assume this is OE0520 - sales order header.
	vDetail = None
	vID = e.wi.getValue("VIEWID")
	if vID == "OE0520":
		# this is the header view. Continue with the sales margin validation.
		vDetail = e.wi.viewobject.findView("OE0500")
		if vDetail == None:
			return 1	# failure.
			
		# else continue:
		sFilter = "LINETYPE = 1"
		vDetail.recordClear()
		vDetail.browse(sFilter,1)
		while vDetail.fetch() == 0:
			# loop through all the item lines:
			if exceedSalesMargin(warningMargin, vDetail) == False:
				r = 1
			
	return r

# This function returns 0 (success) or 1 (failure). The return value is used to determine which action to run next in the workflow.
def workflow(e):
	rvspyTrace("workflow - checkSalesMargin")
	v = e.wi.getView()
	if v == None:
		return 1	# This is actually FALSE, not success.
		
	return checkSalesMargins(e, v)
